# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelOrderRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'billing_address': 'ChannelAddressRequest',
        'shipping_address': 'ChannelAddressRequest',
        'channel_order_no': 'str',
        'is_business_order': 'bool',
        'key_is_merchant_product_no': 'bool',
        'lines': 'list[ChannelOrderLineRequest]',
        'phone': 'str',
        'email': 'str',
        'company_registration_no': 'str',
        'vat_no': 'str',
        'payment_method': 'str',
        'payment_reference_no': 'str',
        'shipping_costs_incl_vat': 'float',
        'currency_code': 'str',
        'order_date': 'datetime',
        'channel_customer_no': 'str',
        'extra_data': 'dict(str, str)'
    }

    attribute_map = {
        'billing_address': 'BillingAddress',
        'shipping_address': 'ShippingAddress',
        'channel_order_no': 'ChannelOrderNo',
        'is_business_order': 'IsBusinessOrder',
        'key_is_merchant_product_no': 'KeyIsMerchantProductNo',
        'lines': 'Lines',
        'phone': 'Phone',
        'email': 'Email',
        'company_registration_no': 'CompanyRegistrationNo',
        'vat_no': 'VatNo',
        'payment_method': 'PaymentMethod',
        'payment_reference_no': 'PaymentReferenceNo',
        'shipping_costs_incl_vat': 'ShippingCostsInclVat',
        'currency_code': 'CurrencyCode',
        'order_date': 'OrderDate',
        'channel_customer_no': 'ChannelCustomerNo',
        'extra_data': 'ExtraData'
    }

    def __init__(self, billing_address=None, shipping_address=None, channel_order_no=None, is_business_order=None, key_is_merchant_product_no=None, lines=None, phone=None, email=None, company_registration_no=None, vat_no=None, payment_method=None, payment_reference_no=None, shipping_costs_incl_vat=None, currency_code=None, order_date=None, channel_customer_no=None, extra_data=None, local_vars_configuration=None):  # noqa: E501
        """ChannelOrderRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._billing_address = None
        self._shipping_address = None
        self._channel_order_no = None
        self._is_business_order = None
        self._key_is_merchant_product_no = None
        self._lines = None
        self._phone = None
        self._email = None
        self._company_registration_no = None
        self._vat_no = None
        self._payment_method = None
        self._payment_reference_no = None
        self._shipping_costs_incl_vat = None
        self._currency_code = None
        self._order_date = None
        self._channel_customer_no = None
        self._extra_data = None
        self.discriminator = None

        self.billing_address = billing_address
        self.shipping_address = shipping_address
        self.channel_order_no = channel_order_no
        self.is_business_order = is_business_order
        if key_is_merchant_product_no is not None:
            self.key_is_merchant_product_no = key_is_merchant_product_no
        self.lines = lines
        self.phone = phone
        self.email = email
        self.company_registration_no = company_registration_no
        self.vat_no = vat_no
        self.payment_method = payment_method
        self.payment_reference_no = payment_reference_no
        self.shipping_costs_incl_vat = shipping_costs_incl_vat
        self.currency_code = currency_code
        self.order_date = order_date
        self.channel_customer_no = channel_customer_no
        self.extra_data = extra_data

    @property
    def billing_address(self):
        """Gets the billing_address of this ChannelOrderRequest.  # noqa: E501

        The billing or invoice address.  # noqa: E501

        :return: The billing_address of this ChannelOrderRequest.  # noqa: E501
        :rtype: ChannelAddressRequest
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this ChannelOrderRequest.

        The billing or invoice address.  # noqa: E501

        :param billing_address: The billing_address of this ChannelOrderRequest.  # noqa: E501
        :type billing_address: ChannelAddressRequest
        """
        if self.local_vars_configuration.client_side_validation and billing_address is None:  # noqa: E501
            raise ValueError("Invalid value for `billing_address`, must not be `None`")  # noqa: E501

        self._billing_address = billing_address

    @property
    def shipping_address(self):
        """Gets the shipping_address of this ChannelOrderRequest.  # noqa: E501

        The shipping address.  # noqa: E501

        :return: The shipping_address of this ChannelOrderRequest.  # noqa: E501
        :rtype: ChannelAddressRequest
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this ChannelOrderRequest.

        The shipping address.  # noqa: E501

        :param shipping_address: The shipping_address of this ChannelOrderRequest.  # noqa: E501
        :type shipping_address: ChannelAddressRequest
        """
        if self.local_vars_configuration.client_side_validation and shipping_address is None:  # noqa: E501
            raise ValueError("Invalid value for `shipping_address`, must not be `None`")  # noqa: E501

        self._shipping_address = shipping_address

    @property
    def channel_order_no(self):
        """Gets the channel_order_no of this ChannelOrderRequest.  # noqa: E501

        The unique order reference used by the Channel.  # noqa: E501

        :return: The channel_order_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._channel_order_no

    @channel_order_no.setter
    def channel_order_no(self, channel_order_no):
        """Sets the channel_order_no of this ChannelOrderRequest.

        The unique order reference used by the Channel.  # noqa: E501

        :param channel_order_no: The channel_order_no of this ChannelOrderRequest.  # noqa: E501
        :type channel_order_no: str
        """
        if self.local_vars_configuration.client_side_validation and channel_order_no is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_order_no`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                channel_order_no is not None and len(channel_order_no) > 60):
            raise ValueError("Invalid value for `channel_order_no`, length must be less than or equal to `60`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                channel_order_no is not None and len(channel_order_no) < 0):
            raise ValueError("Invalid value for `channel_order_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._channel_order_no = channel_order_no

    @property
    def is_business_order(self):
        """Gets the is_business_order of this ChannelOrderRequest.  # noqa: E501

        Optional. Is a business order (default value is false).  If not provided the VAT Number will be checked. If a VAT Number is found, IsBusinessOrder will be set to true.  No VAT will be calculated when set to true.  # noqa: E501

        :return: The is_business_order of this ChannelOrderRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_business_order

    @is_business_order.setter
    def is_business_order(self, is_business_order):
        """Sets the is_business_order of this ChannelOrderRequest.

        Optional. Is a business order (default value is false).  If not provided the VAT Number will be checked. If a VAT Number is found, IsBusinessOrder will be set to true.  No VAT will be calculated when set to true.  # noqa: E501

        :param is_business_order: The is_business_order of this ChannelOrderRequest.  # noqa: E501
        :type is_business_order: bool
        """

        self._is_business_order = is_business_order

    @property
    def key_is_merchant_product_no(self):
        """Gets the key_is_merchant_product_no of this ChannelOrderRequest.  # noqa: E501

        Optional. Is the MPN used as key for the product (default value is false).  # noqa: E501

        :return: The key_is_merchant_product_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: bool
        """
        return self._key_is_merchant_product_no

    @key_is_merchant_product_no.setter
    def key_is_merchant_product_no(self, key_is_merchant_product_no):
        """Sets the key_is_merchant_product_no of this ChannelOrderRequest.

        Optional. Is the MPN used as key for the product (default value is false).  # noqa: E501

        :param key_is_merchant_product_no: The key_is_merchant_product_no of this ChannelOrderRequest.  # noqa: E501
        :type key_is_merchant_product_no: bool
        """

        self._key_is_merchant_product_no = key_is_merchant_product_no

    @property
    def lines(self):
        """Gets the lines of this ChannelOrderRequest.  # noqa: E501

        The order lines.  # noqa: E501

        :return: The lines of this ChannelOrderRequest.  # noqa: E501
        :rtype: list[ChannelOrderLineRequest]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """Sets the lines of this ChannelOrderRequest.

        The order lines.  # noqa: E501

        :param lines: The lines of this ChannelOrderRequest.  # noqa: E501
        :type lines: list[ChannelOrderLineRequest]
        """
        if self.local_vars_configuration.client_side_validation and lines is None:  # noqa: E501
            raise ValueError("Invalid value for `lines`, must not be `None`")  # noqa: E501

        self._lines = lines

    @property
    def phone(self):
        """Gets the phone of this ChannelOrderRequest.  # noqa: E501

        The customer's telephone number.  # noqa: E501

        :return: The phone of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this ChannelOrderRequest.

        The customer's telephone number.  # noqa: E501

        :param phone: The phone of this ChannelOrderRequest.  # noqa: E501
        :type phone: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone is not None and len(phone) > 50):
            raise ValueError("Invalid value for `phone`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                phone is not None and len(phone) < 0):
            raise ValueError("Invalid value for `phone`, length must be greater than or equal to `0`")  # noqa: E501

        self._phone = phone

    @property
    def email(self):
        """Gets the email of this ChannelOrderRequest.  # noqa: E501

        The customer's email.  # noqa: E501

        :return: The email of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ChannelOrderRequest.

        The customer's email.  # noqa: E501

        :param email: The email of this ChannelOrderRequest.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 250):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `250`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 0):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `0`")  # noqa: E501

        self._email = email

    @property
    def company_registration_no(self):
        """Gets the company_registration_no of this ChannelOrderRequest.  # noqa: E501

        Optional. A company's chamber of commerce number.  # noqa: E501

        :return: The company_registration_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._company_registration_no

    @company_registration_no.setter
    def company_registration_no(self, company_registration_no):
        """Sets the company_registration_no of this ChannelOrderRequest.

        Optional. A company's chamber of commerce number.  # noqa: E501

        :param company_registration_no: The company_registration_no of this ChannelOrderRequest.  # noqa: E501
        :type company_registration_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                company_registration_no is not None and len(company_registration_no) > 50):
            raise ValueError("Invalid value for `company_registration_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                company_registration_no is not None and len(company_registration_no) < 0):
            raise ValueError("Invalid value for `company_registration_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._company_registration_no = company_registration_no

    @property
    def vat_no(self):
        """Gets the vat_no of this ChannelOrderRequest.  # noqa: E501

        Optional. A company's VAT number.  # noqa: E501

        :return: The vat_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._vat_no

    @vat_no.setter
    def vat_no(self, vat_no):
        """Sets the vat_no of this ChannelOrderRequest.

        Optional. A company's VAT number.  # noqa: E501

        :param vat_no: The vat_no of this ChannelOrderRequest.  # noqa: E501
        :type vat_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                vat_no is not None and len(vat_no) > 50):
            raise ValueError("Invalid value for `vat_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                vat_no is not None and len(vat_no) < 0):
            raise ValueError("Invalid value for `vat_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._vat_no = vat_no

    @property
    def payment_method(self):
        """Gets the payment_method of this ChannelOrderRequest.  # noqa: E501

        The payment method used on the order.  # noqa: E501

        :return: The payment_method of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this ChannelOrderRequest.

        The payment method used on the order.  # noqa: E501

        :param payment_method: The payment_method of this ChannelOrderRequest.  # noqa: E501
        :type payment_method: str
        """
        if (self.local_vars_configuration.client_side_validation and
                payment_method is not None and len(payment_method) > 50):
            raise ValueError("Invalid value for `payment_method`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                payment_method is not None and len(payment_method) < 0):
            raise ValueError("Invalid value for `payment_method`, length must be greater than or equal to `0`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def payment_reference_no(self):
        """Gets the payment_reference_no of this ChannelOrderRequest.  # noqa: E501

        Reference or transaction id for the payment  # noqa: E501

        :return: The payment_reference_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_reference_no

    @payment_reference_no.setter
    def payment_reference_no(self, payment_reference_no):
        """Sets the payment_reference_no of this ChannelOrderRequest.

        Reference or transaction id for the payment  # noqa: E501

        :param payment_reference_no: The payment_reference_no of this ChannelOrderRequest.  # noqa: E501
        :type payment_reference_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                payment_reference_no is not None and len(payment_reference_no) > 250):
            raise ValueError("Invalid value for `payment_reference_no`, length must be less than or equal to `250`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                payment_reference_no is not None and len(payment_reference_no) < 0):
            raise ValueError("Invalid value for `payment_reference_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._payment_reference_no = payment_reference_no

    @property
    def shipping_costs_incl_vat(self):
        """Gets the shipping_costs_incl_vat of this ChannelOrderRequest.  # noqa: E501

        The shipping fee including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :return: The shipping_costs_incl_vat of this ChannelOrderRequest.  # noqa: E501
        :rtype: float
        """
        return self._shipping_costs_incl_vat

    @shipping_costs_incl_vat.setter
    def shipping_costs_incl_vat(self, shipping_costs_incl_vat):
        """Sets the shipping_costs_incl_vat of this ChannelOrderRequest.

        The shipping fee including VAT  (in the shop's base currency calculated using the exchange rate at the time of ordering).  # noqa: E501

        :param shipping_costs_incl_vat: The shipping_costs_incl_vat of this ChannelOrderRequest.  # noqa: E501
        :type shipping_costs_incl_vat: float
        """
        if self.local_vars_configuration.client_side_validation and shipping_costs_incl_vat is None:  # noqa: E501
            raise ValueError("Invalid value for `shipping_costs_incl_vat`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shipping_costs_incl_vat is not None and shipping_costs_incl_vat < 0):  # noqa: E501
            raise ValueError("Invalid value for `shipping_costs_incl_vat`, must be a value greater than or equal to `0`")  # noqa: E501

        self._shipping_costs_incl_vat = shipping_costs_incl_vat

    @property
    def currency_code(self):
        """Gets the currency_code of this ChannelOrderRequest.  # noqa: E501

        The currency code for the amounts of the order.  # noqa: E501

        :return: The currency_code of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this ChannelOrderRequest.

        The currency code for the amounts of the order.  # noqa: E501

        :param currency_code: The currency_code of this ChannelOrderRequest.  # noqa: E501
        :type currency_code: str
        """
        if self.local_vars_configuration.client_side_validation and currency_code is None:  # noqa: E501
            raise ValueError("Invalid value for `currency_code`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                currency_code is not None and len(currency_code) > 3):
            raise ValueError("Invalid value for `currency_code`, length must be less than or equal to `3`")  # noqa: E501

        self._currency_code = currency_code

    @property
    def order_date(self):
        """Gets the order_date of this ChannelOrderRequest.  # noqa: E501

        The date the order was created at the channel.  # noqa: E501

        :return: The order_date of this ChannelOrderRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._order_date

    @order_date.setter
    def order_date(self, order_date):
        """Sets the order_date of this ChannelOrderRequest.

        The date the order was created at the channel.  # noqa: E501

        :param order_date: The order_date of this ChannelOrderRequest.  # noqa: E501
        :type order_date: datetime
        """
        if self.local_vars_configuration.client_side_validation and order_date is None:  # noqa: E501
            raise ValueError("Invalid value for `order_date`, must not be `None`")  # noqa: E501

        self._order_date = order_date

    @property
    def channel_customer_no(self):
        """Gets the channel_customer_no of this ChannelOrderRequest.  # noqa: E501

        The unique customer reference used by the channel.  # noqa: E501

        :return: The channel_customer_no of this ChannelOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._channel_customer_no

    @channel_customer_no.setter
    def channel_customer_no(self, channel_customer_no):
        """Sets the channel_customer_no of this ChannelOrderRequest.

        The unique customer reference used by the channel.  # noqa: E501

        :param channel_customer_no: The channel_customer_no of this ChannelOrderRequest.  # noqa: E501
        :type channel_customer_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                channel_customer_no is not None and len(channel_customer_no) > 50):
            raise ValueError("Invalid value for `channel_customer_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                channel_customer_no is not None and len(channel_customer_no) < 0):
            raise ValueError("Invalid value for `channel_customer_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._channel_customer_no = channel_customer_no

    @property
    def extra_data(self):
        """Gets the extra_data of this ChannelOrderRequest.  # noqa: E501

        Extra data on the order.  # noqa: E501

        :return: The extra_data of this ChannelOrderRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extra_data

    @extra_data.setter
    def extra_data(self, extra_data):
        """Sets the extra_data of this ChannelOrderRequest.

        Extra data on the order.  # noqa: E501

        :param extra_data: The extra_data of this ChannelOrderRequest.  # noqa: E501
        :type extra_data: dict(str, str)
        """

        self._extra_data = extra_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelOrderRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelOrderRequest):
            return True

        return self.to_dict() != other.to_dict()



"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.13.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from channelengine_channel_api_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from channelengine_channel_api_client.exceptions import ApiAttributeError


def lazy_import():
    from channelengine_channel_api_client.model.channel_product_extra_data_item_response import ChannelProductExtraDataItemResponse
    from channelengine_channel_api_client.model.product_type import ProductType
    from channelengine_channel_api_client.model.vat_rate_type import VatRateType
    globals()['ChannelProductExtraDataItemResponse'] = ChannelProductExtraDataItemResponse
    globals()['ProductType'] = ProductType
    globals()['VatRateType'] = VatRateType


class ChannelProductResponse(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('merchant_product_no',): {
            'max_length': 64,
            'min_length': 0,
        },
        ('name',): {
            'max_length': 256,
            'min_length': 0,
        },
        ('brand',): {
            'max_length': 256,
            'min_length': 0,
        },
        ('size',): {
            'max_length': 64,
            'min_length': 0,
        },
        ('color',): {
            'max_length': 64,
            'min_length': 0,
        },
        ('ean',): {
            'max_length': 64,
            'min_length': 0,
        },
        ('manufacturer_product_number',): {
            'max_length': 64,
            'min_length': 0,
        },
        ('stock',): {
            'inclusive_minimum': 0,
        },
        ('price',): {
            'inclusive_minimum': 0,
        },
        ('shipping_time',): {
            'max_length': 128,
            'min_length': 0,
        },
        ('url',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('image_url',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url1',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url2',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url3',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url4',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url5',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url6',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url7',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url8',): {
            'max_length': 512,
            'min_length': 0,
        },
        ('extra_image_url9',): {
            'max_length': 512,
            'min_length': 0,
        },
    }

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'merchant_product_no': (str,),  # noqa: E501
            'id': (int,),  # noqa: E501
            'channel_product_no': (str, none_type,),  # noqa: E501
            'parent_channel_product_no': (str, none_type,),  # noqa: E501
            'grandparent_channel_product_no': (str, none_type,),  # noqa: E501
            'mapped_fields': ({str: (str,)}, none_type,),  # noqa: E501
            'product_type': (ProductType,),  # noqa: E501
            'extra_data': ([ChannelProductExtraDataItemResponse], none_type,),  # noqa: E501
            'name': (str, none_type,),  # noqa: E501
            'description': (str, none_type,),  # noqa: E501
            'brand': (str, none_type,),  # noqa: E501
            'size': (str, none_type,),  # noqa: E501
            'color': (str, none_type,),  # noqa: E501
            'ean': (str, none_type,),  # noqa: E501
            'manufacturer_product_number': (str, none_type,),  # noqa: E501
            'stock': (int,),  # noqa: E501
            'price': (float,),  # noqa: E501
            'msrp': (float, none_type,),  # noqa: E501
            'purchase_price': (float, none_type,),  # noqa: E501
            'vat_rate_type': (VatRateType,),  # noqa: E501
            'shipping_cost': (float, none_type,),  # noqa: E501
            'shipping_time': (str, none_type,),  # noqa: E501
            'url': (str, none_type,),  # noqa: E501
            'image_url': (str, none_type,),  # noqa: E501
            'extra_image_url1': (str, none_type,),  # noqa: E501
            'extra_image_url2': (str, none_type,),  # noqa: E501
            'extra_image_url3': (str, none_type,),  # noqa: E501
            'extra_image_url4': (str, none_type,),  # noqa: E501
            'extra_image_url5': (str, none_type,),  # noqa: E501
            'extra_image_url6': (str, none_type,),  # noqa: E501
            'extra_image_url7': (str, none_type,),  # noqa: E501
            'extra_image_url8': (str, none_type,),  # noqa: E501
            'extra_image_url9': (str, none_type,),  # noqa: E501
            'category_trail': (str, none_type,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'merchant_product_no': 'MerchantProductNo',  # noqa: E501
        'id': 'Id',  # noqa: E501
        'channel_product_no': 'ChannelProductNo',  # noqa: E501
        'parent_channel_product_no': 'ParentChannelProductNo',  # noqa: E501
        'grandparent_channel_product_no': 'GrandparentChannelProductNo',  # noqa: E501
        'mapped_fields': 'MappedFields',  # noqa: E501
        'product_type': 'ProductType',  # noqa: E501
        'extra_data': 'ExtraData',  # noqa: E501
        'name': 'Name',  # noqa: E501
        'description': 'Description',  # noqa: E501
        'brand': 'Brand',  # noqa: E501
        'size': 'Size',  # noqa: E501
        'color': 'Color',  # noqa: E501
        'ean': 'Ean',  # noqa: E501
        'manufacturer_product_number': 'ManufacturerProductNumber',  # noqa: E501
        'stock': 'Stock',  # noqa: E501
        'price': 'Price',  # noqa: E501
        'msrp': 'MSRP',  # noqa: E501
        'purchase_price': 'PurchasePrice',  # noqa: E501
        'vat_rate_type': 'VatRateType',  # noqa: E501
        'shipping_cost': 'ShippingCost',  # noqa: E501
        'shipping_time': 'ShippingTime',  # noqa: E501
        'url': 'Url',  # noqa: E501
        'image_url': 'ImageUrl',  # noqa: E501
        'extra_image_url1': 'ExtraImageUrl1',  # noqa: E501
        'extra_image_url2': 'ExtraImageUrl2',  # noqa: E501
        'extra_image_url3': 'ExtraImageUrl3',  # noqa: E501
        'extra_image_url4': 'ExtraImageUrl4',  # noqa: E501
        'extra_image_url5': 'ExtraImageUrl5',  # noqa: E501
        'extra_image_url6': 'ExtraImageUrl6',  # noqa: E501
        'extra_image_url7': 'ExtraImageUrl7',  # noqa: E501
        'extra_image_url8': 'ExtraImageUrl8',  # noqa: E501
        'extra_image_url9': 'ExtraImageUrl9',  # noqa: E501
        'category_trail': 'CategoryTrail',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, merchant_product_no, *args, **kwargs):  # noqa: E501
        """ChannelProductResponse - a model defined in OpenAPI

        Args:
            merchant_product_no (str): A unique identifier of the product. (sku).

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (int): An unique identifier which ChannelEngine uses to identify the product.  Needed in the call 'POST /v2/products/data'.. [optional]  # noqa: E501
            channel_product_no (str, none_type): The unique product reference used by the Channel for the product.. [optional]  # noqa: E501
            parent_channel_product_no (str, none_type): The unique product reference used by the Channel for the parent product.. [optional]  # noqa: E501
            grandparent_channel_product_no (str, none_type): The unique product reference used by the Channel for the grandparent product.. [optional]  # noqa: E501
            mapped_fields ({str: (str,)}, none_type): A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.. [optional]  # noqa: E501
            product_type (ProductType): [optional]  # noqa: E501
            extra_data ([ChannelProductExtraDataItemResponse], none_type): An optional list of key-value pairs containing  extra data about this product. This data can be  sent to channels or used for filtering products.. [optional]  # noqa: E501
            name (str, none_type): The name of the product.. [optional]  # noqa: E501
            description (str, none_type): A description of the product. Can contain these HTML tags:  div, span, pre, p, br, hr, hgroup, h1, h2, h3, h4, h5, h6, ul, ol, li, dl, dt, dd, strong, em, b, i, u, img, a, abbr, address, blockquote, area, audio, video, caption, table, tbody, td, tfoot, th, thead, tr.. [optional]  # noqa: E501
            brand (str, none_type): The brand of the product.. [optional]  # noqa: E501
            size (str, none_type): Optional. The size of the product (variant). E.g. fashion size (S-XL, 46-56, etc), width of the watch, etc... [optional]  # noqa: E501
            color (str, none_type): Optional. The color of the product (variant).. [optional]  # noqa: E501
            ean (str, none_type): The EAN of GTIN of the product.. [optional]  # noqa: E501
            manufacturer_product_number (str, none_type): The unique product reference used by the manufacturer/vendor of the product.. [optional]  # noqa: E501
            stock (int): The number of items in stock.. [optional]  # noqa: E501
            price (float): Price, including VAT.. [optional]  # noqa: E501
            msrp (float, none_type): Manufacturer's suggested retail price.. [optional]  # noqa: E501
            purchase_price (float, none_type): Optional. The purchase price of the product. Useful for repricing.. [optional]  # noqa: E501
            vat_rate_type (VatRateType): [optional]  # noqa: E501
            shipping_cost (float, none_type): Shipping cost of the product.. [optional]  # noqa: E501
            shipping_time (str, none_type): A textual representation of the shippingtime.  For example, in Dutch: 'Op werkdagen voor 22:00 uur besteld, morgen in huis'.. [optional]  # noqa: E501
            url (str, none_type): A URL pointing to the merchant's webpage  which displays this product.. [optional]  # noqa: E501
            image_url (str, none_type): A URL at which an image of this product  can be found.. [optional]  # noqa: E501
            extra_image_url1 (str, none_type): Url to an additional image of product (1).. [optional]  # noqa: E501
            extra_image_url2 (str, none_type): Url to an additional image of product (2).. [optional]  # noqa: E501
            extra_image_url3 (str, none_type): Url to an additional image of product (3).. [optional]  # noqa: E501
            extra_image_url4 (str, none_type): Url to an additional image of product (4).. [optional]  # noqa: E501
            extra_image_url5 (str, none_type): Url to an additional image of product (5).. [optional]  # noqa: E501
            extra_image_url6 (str, none_type): Url to an additional image of product (6).. [optional]  # noqa: E501
            extra_image_url7 (str, none_type): Url to an additional image of product (7).. [optional]  # noqa: E501
            extra_image_url8 (str, none_type): Url to an additional image of product (8).. [optional]  # noqa: E501
            extra_image_url9 (str, none_type): Url to an additional image of product (9).. [optional]  # noqa: E501
            category_trail (str, none_type): The category to which this product belongs.  Please supply this field in the following format:  'maincategory > category > subcategory'  For example:  'vehicles > bikes > mountainbike'.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.merchant_product_no = merchant_product_no
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, merchant_product_no, *args, **kwargs):  # noqa: E501
        """ChannelProductResponse - a model defined in OpenAPI

        Args:
            merchant_product_no (str): A unique identifier of the product. (sku).

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (int): An unique identifier which ChannelEngine uses to identify the product.  Needed in the call 'POST /v2/products/data'.. [optional]  # noqa: E501
            channel_product_no (str, none_type): The unique product reference used by the Channel for the product.. [optional]  # noqa: E501
            parent_channel_product_no (str, none_type): The unique product reference used by the Channel for the parent product.. [optional]  # noqa: E501
            grandparent_channel_product_no (str, none_type): The unique product reference used by the Channel for the grandparent product.. [optional]  # noqa: E501
            mapped_fields ({str: (str,)}, none_type): A channel can require certain fields to be available. The channel  can provide ChannelEngine with this fields after which the merchants  will be able to fill in this field using custom conditions in ChannelEngine.. [optional]  # noqa: E501
            product_type (ProductType): [optional]  # noqa: E501
            extra_data ([ChannelProductExtraDataItemResponse], none_type): An optional list of key-value pairs containing  extra data about this product. This data can be  sent to channels or used for filtering products.. [optional]  # noqa: E501
            name (str, none_type): The name of the product.. [optional]  # noqa: E501
            description (str, none_type): A description of the product. Can contain these HTML tags:  div, span, pre, p, br, hr, hgroup, h1, h2, h3, h4, h5, h6, ul, ol, li, dl, dt, dd, strong, em, b, i, u, img, a, abbr, address, blockquote, area, audio, video, caption, table, tbody, td, tfoot, th, thead, tr.. [optional]  # noqa: E501
            brand (str, none_type): The brand of the product.. [optional]  # noqa: E501
            size (str, none_type): Optional. The size of the product (variant). E.g. fashion size (S-XL, 46-56, etc), width of the watch, etc... [optional]  # noqa: E501
            color (str, none_type): Optional. The color of the product (variant).. [optional]  # noqa: E501
            ean (str, none_type): The EAN of GTIN of the product.. [optional]  # noqa: E501
            manufacturer_product_number (str, none_type): The unique product reference used by the manufacturer/vendor of the product.. [optional]  # noqa: E501
            stock (int): The number of items in stock.. [optional]  # noqa: E501
            price (float): Price, including VAT.. [optional]  # noqa: E501
            msrp (float, none_type): Manufacturer's suggested retail price.. [optional]  # noqa: E501
            purchase_price (float, none_type): Optional. The purchase price of the product. Useful for repricing.. [optional]  # noqa: E501
            vat_rate_type (VatRateType): [optional]  # noqa: E501
            shipping_cost (float, none_type): Shipping cost of the product.. [optional]  # noqa: E501
            shipping_time (str, none_type): A textual representation of the shippingtime.  For example, in Dutch: 'Op werkdagen voor 22:00 uur besteld, morgen in huis'.. [optional]  # noqa: E501
            url (str, none_type): A URL pointing to the merchant's webpage  which displays this product.. [optional]  # noqa: E501
            image_url (str, none_type): A URL at which an image of this product  can be found.. [optional]  # noqa: E501
            extra_image_url1 (str, none_type): Url to an additional image of product (1).. [optional]  # noqa: E501
            extra_image_url2 (str, none_type): Url to an additional image of product (2).. [optional]  # noqa: E501
            extra_image_url3 (str, none_type): Url to an additional image of product (3).. [optional]  # noqa: E501
            extra_image_url4 (str, none_type): Url to an additional image of product (4).. [optional]  # noqa: E501
            extra_image_url5 (str, none_type): Url to an additional image of product (5).. [optional]  # noqa: E501
            extra_image_url6 (str, none_type): Url to an additional image of product (6).. [optional]  # noqa: E501
            extra_image_url7 (str, none_type): Url to an additional image of product (7).. [optional]  # noqa: E501
            extra_image_url8 (str, none_type): Url to an additional image of product (8).. [optional]  # noqa: E501
            extra_image_url9 (str, none_type): Url to an additional image of product (9).. [optional]  # noqa: E501
            category_trail (str, none_type): The category to which this product belongs.  Please supply this field in the following format:  'maincategory > category > subcategory'  For example:  'vehicles > bikes > mountainbike'.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.merchant_product_no = merchant_product_no
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelShipmentResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'channel_order_no': 'str',
        'lines': 'list[ChannelShipmentLineResponse]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'extra_data': 'dict(str, str)',
        'track_trace_no': 'str',
        'track_trace_url': 'str',
        'return_track_trace_no': 'str',
        'method': 'str',
        'shipped_from_country_code': 'str'
    }

    attribute_map = {
        'channel_order_no': 'ChannelOrderNo',
        'lines': 'Lines',
        'created_at': 'CreatedAt',
        'updated_at': 'UpdatedAt',
        'extra_data': 'ExtraData',
        'track_trace_no': 'TrackTraceNo',
        'track_trace_url': 'TrackTraceUrl',
        'return_track_trace_no': 'ReturnTrackTraceNo',
        'method': 'Method',
        'shipped_from_country_code': 'ShippedFromCountryCode'
    }

    def __init__(self, channel_order_no=None, lines=None, created_at=None, updated_at=None, extra_data=None, track_trace_no=None, track_trace_url=None, return_track_trace_no=None, method=None, shipped_from_country_code=None, local_vars_configuration=None):  # noqa: E501
        """ChannelShipmentResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._channel_order_no = None
        self._lines = None
        self._created_at = None
        self._updated_at = None
        self._extra_data = None
        self._track_trace_no = None
        self._track_trace_url = None
        self._return_track_trace_no = None
        self._method = None
        self._shipped_from_country_code = None
        self.discriminator = None

        self.channel_order_no = channel_order_no
        self.lines = lines
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        self.extra_data = extra_data
        self.track_trace_no = track_trace_no
        self.track_trace_url = track_trace_url
        self.return_track_trace_no = return_track_trace_no
        self.method = method
        self.shipped_from_country_code = shipped_from_country_code

    @property
    def channel_order_no(self):
        """Gets the channel_order_no of this ChannelShipmentResponse.  # noqa: E501

        The unique order reference used by the Channel.  # noqa: E501

        :return: The channel_order_no of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._channel_order_no

    @channel_order_no.setter
    def channel_order_no(self, channel_order_no):
        """Sets the channel_order_no of this ChannelShipmentResponse.

        The unique order reference used by the Channel.  # noqa: E501

        :param channel_order_no: The channel_order_no of this ChannelShipmentResponse.  # noqa: E501
        :type channel_order_no: str
        """
        if self.local_vars_configuration.client_side_validation and channel_order_no is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_order_no`, must not be `None`")  # noqa: E501

        self._channel_order_no = channel_order_no

    @property
    def lines(self):
        """Gets the lines of this ChannelShipmentResponse.  # noqa: E501


        :return: The lines of this ChannelShipmentResponse.  # noqa: E501
        :rtype: list[ChannelShipmentLineResponse]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """Sets the lines of this ChannelShipmentResponse.


        :param lines: The lines of this ChannelShipmentResponse.  # noqa: E501
        :type lines: list[ChannelShipmentLineResponse]
        """
        if self.local_vars_configuration.client_side_validation and lines is None:  # noqa: E501
            raise ValueError("Invalid value for `lines`, must not be `None`")  # noqa: E501

        self._lines = lines

    @property
    def created_at(self):
        """Gets the created_at of this ChannelShipmentResponse.  # noqa: E501

        The date at which the shipment was created in ChannelEngine.  # noqa: E501

        :return: The created_at of this ChannelShipmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ChannelShipmentResponse.

        The date at which the shipment was created in ChannelEngine.  # noqa: E501

        :param created_at: The created_at of this ChannelShipmentResponse.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ChannelShipmentResponse.  # noqa: E501

        The date at which the shipment was last modified in ChannelEngine.  # noqa: E501

        :return: The updated_at of this ChannelShipmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ChannelShipmentResponse.

        The date at which the shipment was last modified in ChannelEngine.  # noqa: E501

        :param updated_at: The updated_at of this ChannelShipmentResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    @property
    def extra_data(self):
        """Gets the extra_data of this ChannelShipmentResponse.  # noqa: E501

        Extra data on the order. Each item must have an unqiue key  # noqa: E501

        :return: The extra_data of this ChannelShipmentResponse.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extra_data

    @extra_data.setter
    def extra_data(self, extra_data):
        """Sets the extra_data of this ChannelShipmentResponse.

        Extra data on the order. Each item must have an unqiue key  # noqa: E501

        :param extra_data: The extra_data of this ChannelShipmentResponse.  # noqa: E501
        :type extra_data: dict(str, str)
        """

        self._extra_data = extra_data

    @property
    def track_trace_no(self):
        """Gets the track_trace_no of this ChannelShipmentResponse.  # noqa: E501

        The unique shipping reference used by the Shipping carrier (track&trace number).  # noqa: E501

        :return: The track_trace_no of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._track_trace_no

    @track_trace_no.setter
    def track_trace_no(self, track_trace_no):
        """Sets the track_trace_no of this ChannelShipmentResponse.

        The unique shipping reference used by the Shipping carrier (track&trace number).  # noqa: E501

        :param track_trace_no: The track_trace_no of this ChannelShipmentResponse.  # noqa: E501
        :type track_trace_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                track_trace_no is not None and len(track_trace_no) > 50):
            raise ValueError("Invalid value for `track_trace_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                track_trace_no is not None and len(track_trace_no) < 0):
            raise ValueError("Invalid value for `track_trace_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._track_trace_no = track_trace_no

    @property
    def track_trace_url(self):
        """Gets the track_trace_url of this ChannelShipmentResponse.  # noqa: E501

        A link to a page of the carrier where the customer can track the shipping of her package.  # noqa: E501

        :return: The track_trace_url of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._track_trace_url

    @track_trace_url.setter
    def track_trace_url(self, track_trace_url):
        """Sets the track_trace_url of this ChannelShipmentResponse.

        A link to a page of the carrier where the customer can track the shipping of her package.  # noqa: E501

        :param track_trace_url: The track_trace_url of this ChannelShipmentResponse.  # noqa: E501
        :type track_trace_url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                track_trace_url is not None and len(track_trace_url) > 250):
            raise ValueError("Invalid value for `track_trace_url`, length must be less than or equal to `250`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                track_trace_url is not None and len(track_trace_url) < 0):
            raise ValueError("Invalid value for `track_trace_url`, length must be greater than or equal to `0`")  # noqa: E501

        self._track_trace_url = track_trace_url

    @property
    def return_track_trace_no(self):
        """Gets the return_track_trace_no of this ChannelShipmentResponse.  # noqa: E501

        The unique return shipping reference that may be used by the Shipping carrier (track & trace number) if the shipment is returned.  # noqa: E501

        :return: The return_track_trace_no of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._return_track_trace_no

    @return_track_trace_no.setter
    def return_track_trace_no(self, return_track_trace_no):
        """Sets the return_track_trace_no of this ChannelShipmentResponse.

        The unique return shipping reference that may be used by the Shipping carrier (track & trace number) if the shipment is returned.  # noqa: E501

        :param return_track_trace_no: The return_track_trace_no of this ChannelShipmentResponse.  # noqa: E501
        :type return_track_trace_no: str
        """
        if (self.local_vars_configuration.client_side_validation and
                return_track_trace_no is not None and len(return_track_trace_no) > 50):
            raise ValueError("Invalid value for `return_track_trace_no`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                return_track_trace_no is not None and len(return_track_trace_no) < 0):
            raise ValueError("Invalid value for `return_track_trace_no`, length must be greater than or equal to `0`")  # noqa: E501

        self._return_track_trace_no = return_track_trace_no

    @property
    def method(self):
        """Gets the method of this ChannelShipmentResponse.  # noqa: E501

        Shipment method: the carrier used for shipping the package. E.g. DHL, postNL.  # noqa: E501

        :return: The method of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this ChannelShipmentResponse.

        Shipment method: the carrier used for shipping the package. E.g. DHL, postNL.  # noqa: E501

        :param method: The method of this ChannelShipmentResponse.  # noqa: E501
        :type method: str
        """
        if (self.local_vars_configuration.client_side_validation and
                method is not None and len(method) > 50):
            raise ValueError("Invalid value for `method`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                method is not None and len(method) < 0):
            raise ValueError("Invalid value for `method`, length must be greater than or equal to `0`")  # noqa: E501

        self._method = method

    @property
    def shipped_from_country_code(self):
        """Gets the shipped_from_country_code of this ChannelShipmentResponse.  # noqa: E501

        The code of the country from where the package is being shipped.  # noqa: E501

        :return: The shipped_from_country_code of this ChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._shipped_from_country_code

    @shipped_from_country_code.setter
    def shipped_from_country_code(self, shipped_from_country_code):
        """Sets the shipped_from_country_code of this ChannelShipmentResponse.

        The code of the country from where the package is being shipped.  # noqa: E501

        :param shipped_from_country_code: The shipped_from_country_code of this ChannelShipmentResponse.  # noqa: E501
        :type shipped_from_country_code: str
        """
        if (self.local_vars_configuration.client_side_validation and
                shipped_from_country_code is not None and len(shipped_from_country_code) > 3):
            raise ValueError("Invalid value for `shipped_from_country_code`, length must be less than or equal to `3`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                shipped_from_country_code is not None and len(shipped_from_country_code) < 0):
            raise ValueError("Invalid value for `shipped_from_country_code`, length must be greater than or equal to `0`")  # noqa: E501

        self._shipped_from_country_code = shipped_from_country_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelShipmentResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelShipmentResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class CollectionOfChannelShipmentResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'list[ChannelShipmentResponse]',
        'count': 'int',
        'total_count': 'int',
        'items_per_page': 'int',
        'status_code': 'int',
        'log_id': 'int',
        'success': 'bool',
        'message': 'str',
        'validation_errors': 'dict(str, list[str])'
    }

    attribute_map = {
        'content': 'Content',
        'count': 'Count',
        'total_count': 'TotalCount',
        'items_per_page': 'ItemsPerPage',
        'status_code': 'StatusCode',
        'log_id': 'LogId',
        'success': 'Success',
        'message': 'Message',
        'validation_errors': 'ValidationErrors'
    }

    def __init__(self, content=None, count=None, total_count=None, items_per_page=None, status_code=None, log_id=None, success=None, message=None, validation_errors=None, local_vars_configuration=None):  # noqa: E501
        """CollectionOfChannelShipmentResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._count = None
        self._total_count = None
        self._items_per_page = None
        self._status_code = None
        self._log_id = None
        self._success = None
        self._message = None
        self._validation_errors = None
        self.discriminator = None

        self.content = content
        if count is not None:
            self.count = count
        if total_count is not None:
            self.total_count = total_count
        if items_per_page is not None:
            self.items_per_page = items_per_page
        if status_code is not None:
            self.status_code = status_code
        self.log_id = log_id
        if success is not None:
            self.success = success
        self.message = message
        self.validation_errors = validation_errors

    @property
    def content(self):
        """Gets the content of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The content of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: list[ChannelShipmentResponse]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this CollectionOfChannelShipmentResponse.


        :param content: The content of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type content: list[ChannelShipmentResponse]
        """

        self._content = content

    @property
    def count(self):
        """Gets the count of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The count of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this CollectionOfChannelShipmentResponse.


        :param count: The count of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type count: int
        """

        self._count = count

    @property
    def total_count(self):
        """Gets the total_count of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The total_count of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this CollectionOfChannelShipmentResponse.


        :param total_count: The total_count of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type total_count: int
        """

        self._total_count = total_count

    @property
    def items_per_page(self):
        """Gets the items_per_page of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The items_per_page of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._items_per_page

    @items_per_page.setter
    def items_per_page(self, items_per_page):
        """Sets the items_per_page of this CollectionOfChannelShipmentResponse.


        :param items_per_page: The items_per_page of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type items_per_page: int
        """

        self._items_per_page = items_per_page

    @property
    def status_code(self):
        """Gets the status_code of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The status_code of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this CollectionOfChannelShipmentResponse.


        :param status_code: The status_code of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type status_code: int
        """

        self._status_code = status_code

    @property
    def log_id(self):
        """Gets the log_id of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The log_id of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: int
        """
        return self._log_id

    @log_id.setter
    def log_id(self, log_id):
        """Sets the log_id of this CollectionOfChannelShipmentResponse.


        :param log_id: The log_id of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type log_id: int
        """

        self._log_id = log_id

    @property
    def success(self):
        """Gets the success of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The success of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this CollectionOfChannelShipmentResponse.


        :param success: The success of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type success: bool
        """

        self._success = success

    @property
    def message(self):
        """Gets the message of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The message of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this CollectionOfChannelShipmentResponse.


        :param message: The message of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def validation_errors(self):
        """Gets the validation_errors of this CollectionOfChannelShipmentResponse.  # noqa: E501


        :return: The validation_errors of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this CollectionOfChannelShipmentResponse.


        :param validation_errors: The validation_errors of this CollectionOfChannelShipmentResponse.  # noqa: E501
        :type validation_errors: dict(str, list[str])
        """

        self._validation_errors = validation_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionOfChannelShipmentResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionOfChannelShipmentResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelCancellationResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'channel_order_no': 'str',
        'lines': 'list[ChannelCancellationLineResponse]',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'reason': 'str',
        'reason_code': 'MancoReason'
    }

    attribute_map = {
        'channel_order_no': 'ChannelOrderNo',
        'lines': 'Lines',
        'created_at': 'CreatedAt',
        'updated_at': 'UpdatedAt',
        'reason': 'Reason',
        'reason_code': 'ReasonCode'
    }

    def __init__(self, channel_order_no=None, lines=None, created_at=None, updated_at=None, reason=None, reason_code=None, local_vars_configuration=None):  # noqa: E501
        """ChannelCancellationResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._channel_order_no = None
        self._lines = None
        self._created_at = None
        self._updated_at = None
        self._reason = None
        self._reason_code = None
        self.discriminator = None

        self.channel_order_no = channel_order_no
        self.lines = lines
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        self.reason = reason
        self.reason_code = reason_code

    @property
    def channel_order_no(self):
        """Gets the channel_order_no of this ChannelCancellationResponse.  # noqa: E501

        The unique order reference used by the Channel.  # noqa: E501

        :return: The channel_order_no of this ChannelCancellationResponse.  # noqa: E501
        :rtype: str
        """
        return self._channel_order_no

    @channel_order_no.setter
    def channel_order_no(self, channel_order_no):
        """Sets the channel_order_no of this ChannelCancellationResponse.

        The unique order reference used by the Channel.  # noqa: E501

        :param channel_order_no: The channel_order_no of this ChannelCancellationResponse.  # noqa: E501
        :type channel_order_no: str
        """
        if self.local_vars_configuration.client_side_validation and channel_order_no is None:  # noqa: E501
            raise ValueError("Invalid value for `channel_order_no`, must not be `None`")  # noqa: E501

        self._channel_order_no = channel_order_no

    @property
    def lines(self):
        """Gets the lines of this ChannelCancellationResponse.  # noqa: E501


        :return: The lines of this ChannelCancellationResponse.  # noqa: E501
        :rtype: list[ChannelCancellationLineResponse]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """Sets the lines of this ChannelCancellationResponse.


        :param lines: The lines of this ChannelCancellationResponse.  # noqa: E501
        :type lines: list[ChannelCancellationLineResponse]
        """
        if self.local_vars_configuration.client_side_validation and lines is None:  # noqa: E501
            raise ValueError("Invalid value for `lines`, must not be `None`")  # noqa: E501

        self._lines = lines

    @property
    def created_at(self):
        """Gets the created_at of this ChannelCancellationResponse.  # noqa: E501

        The date at which the cancellation was created in ChannelEngine.  # noqa: E501

        :return: The created_at of this ChannelCancellationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ChannelCancellationResponse.

        The date at which the cancellation was created in ChannelEngine.  # noqa: E501

        :param created_at: The created_at of this ChannelCancellationResponse.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this ChannelCancellationResponse.  # noqa: E501

        The date at which the cancellation was last modified in ChannelEngine.  # noqa: E501

        :return: The updated_at of this ChannelCancellationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ChannelCancellationResponse.

        The date at which the cancellation was last modified in ChannelEngine.  # noqa: E501

        :param updated_at: The updated_at of this ChannelCancellationResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    @property
    def reason(self):
        """Gets the reason of this ChannelCancellationResponse.  # noqa: E501

        Reason for cancellation (text).  # noqa: E501

        :return: The reason of this ChannelCancellationResponse.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this ChannelCancellationResponse.

        Reason for cancellation (text).  # noqa: E501

        :param reason: The reason of this ChannelCancellationResponse.  # noqa: E501
        :type reason: str
        """

        self._reason = reason

    @property
    def reason_code(self):
        """Gets the reason_code of this ChannelCancellationResponse.  # noqa: E501

        Reason code for cancellation.  # noqa: E501

        :return: The reason_code of this ChannelCancellationResponse.  # noqa: E501
        :rtype: MancoReason
        """
        return self._reason_code

    @reason_code.setter
    def reason_code(self, reason_code):
        """Sets the reason_code of this ChannelCancellationResponse.

        Reason code for cancellation.  # noqa: E501

        :param reason_code: The reason_code of this ChannelCancellationResponse.  # noqa: E501
        :type reason_code: MancoReason
        """

        self._reason_code = reason_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelCancellationResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelCancellationResponse):
            return True

        return self.to_dict() != other.to_dict()



"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.13.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from channelengine_channel_api_client.api_client import ApiClient, Endpoint as _Endpoint
from channelengine_channel_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from channelengine_channel_api_client.model.api_response import ApiResponse
from channelengine_channel_api_client.model.channel_return_request import ChannelReturnRequest
from channelengine_channel_api_client.model.collection_of_channel_return_response import CollectionOfChannelReturnResponse
from channelengine_channel_api_client.model.return_reason import ReturnReason
from channelengine_channel_api_client.model.return_status import ReturnStatus


class ReturnApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.return_declare_for_channel_endpoint = _Endpoint(
            settings={
                'response_type': (ApiResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/returns/channel',
                'operation_id': 'return_declare_for_channel',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'channel_return_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'channel_return_request':
                        (ChannelReturnRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'channel_return_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json-patch+json',
                    'application/json',
                    'application/*+json'
                ]
            },
            api_client=api_client
        )
        self.return_get_declared_by_merchant_endpoint = _Endpoint(
            settings={
                'response_type': (CollectionOfChannelReturnResponse,),
                'auth': [
                    'apiKey'
                ],
                'endpoint_path': '/v2/returns/channel',
                'operation_id': 'return_get_declared_by_merchant',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'statuses',
                    'reasons',
                    'from_date',
                    'to_date',
                    'is_acknowledged',
                    'page',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'statuses':
                        ([ReturnStatus],),
                    'reasons':
                        ([ReturnReason],),
                    'from_date':
                        (datetime,),
                    'to_date':
                        (datetime,),
                    'is_acknowledged':
                        (bool,),
                    'page':
                        (int,),
                },
                'attribute_map': {
                    'statuses': 'statuses',
                    'reasons': 'reasons',
                    'from_date': 'fromDate',
                    'to_date': 'toDate',
                    'is_acknowledged': 'isAcknowledged',
                    'page': 'page',
                },
                'location_map': {
                    'statuses': 'query',
                    'reasons': 'query',
                    'from_date': 'query',
                    'to_date': 'query',
                    'is_acknowledged': 'query',
                    'page': 'query',
                },
                'collection_format_map': {
                    'statuses': 'multi',
                    'reasons': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def return_declare_for_channel(
        self,
        **kwargs
    ):
        """Create Return.  # noqa: E501

        Mark (part of) an order as returned by the customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.return_declare_for_channel(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            channel_return_request (ChannelReturnRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ApiResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.return_declare_for_channel_endpoint.call_with_http_info(**kwargs)

    def return_get_declared_by_merchant(
        self,
        **kwargs
    ):
        """Get Returns.  # noqa: E501

        Get all returns created by the merchant. This call is supposed<br />to be used by channels. Merchants should use the 'GET /v2/returns/merchant'<br />call.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.return_get_declared_by_merchant(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            statuses ([ReturnStatus]): Return status(es) to filter on.. [optional]
            reasons ([ReturnReason]): Return reason(s) to filter on.. [optional]
            from_date (datetime): Filter on the creation date, starting from this date. This date is inclusive.. [optional]
            to_date (datetime): Filter on the creation date, until this date. This date is exclusive.. [optional]
            is_acknowledged (bool): Filters based on acknowledgements. [optional]
            page (int): The page to filter on. Starts at 1.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CollectionOfChannelReturnResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.return_get_declared_by_merchant_endpoint.call_with_http_info(**kwargs)




# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ApiResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status_code': 'int',
        'log_id': 'int',
        'success': 'bool',
        'message': 'str',
        'validation_errors': 'dict(str, list[str])'
    }

    attribute_map = {
        'status_code': 'StatusCode',
        'log_id': 'LogId',
        'success': 'Success',
        'message': 'Message',
        'validation_errors': 'ValidationErrors'
    }

    def __init__(self, status_code=None, log_id=None, success=None, message=None, validation_errors=None, local_vars_configuration=None):  # noqa: E501
        """ApiResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status_code = None
        self._log_id = None
        self._success = None
        self._message = None
        self._validation_errors = None
        self.discriminator = None

        if status_code is not None:
            self.status_code = status_code
        self.log_id = log_id
        if success is not None:
            self.success = success
        self.message = message
        self.validation_errors = validation_errors

    @property
    def status_code(self):
        """Gets the status_code of this ApiResponse.  # noqa: E501


        :return: The status_code of this ApiResponse.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ApiResponse.


        :param status_code: The status_code of this ApiResponse.  # noqa: E501
        :type status_code: int
        """

        self._status_code = status_code

    @property
    def log_id(self):
        """Gets the log_id of this ApiResponse.  # noqa: E501


        :return: The log_id of this ApiResponse.  # noqa: E501
        :rtype: int
        """
        return self._log_id

    @log_id.setter
    def log_id(self, log_id):
        """Sets the log_id of this ApiResponse.


        :param log_id: The log_id of this ApiResponse.  # noqa: E501
        :type log_id: int
        """

        self._log_id = log_id

    @property
    def success(self):
        """Gets the success of this ApiResponse.  # noqa: E501


        :return: The success of this ApiResponse.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this ApiResponse.


        :param success: The success of this ApiResponse.  # noqa: E501
        :type success: bool
        """

        self._success = success

    @property
    def message(self):
        """Gets the message of this ApiResponse.  # noqa: E501


        :return: The message of this ApiResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ApiResponse.


        :param message: The message of this ApiResponse.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def validation_errors(self):
        """Gets the validation_errors of this ApiResponse.  # noqa: E501


        :return: The validation_errors of this ApiResponse.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this ApiResponse.


        :param validation_errors: The validation_errors of this ApiResponse.  # noqa: E501
        :type validation_errors: dict(str, list[str])
        """

        self._validation_errors = validation_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelAddressRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'gender': 'Gender',
        'company_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'street_name': 'str',
        'house_nr': 'str',
        'house_nr_addition': 'str',
        'zip_code': 'str',
        'city': 'str',
        'region': 'str',
        'country_iso': 'str',
        'original': 'str'
    }

    attribute_map = {
        'gender': 'Gender',
        'company_name': 'CompanyName',
        'first_name': 'FirstName',
        'last_name': 'LastName',
        'street_name': 'StreetName',
        'house_nr': 'HouseNr',
        'house_nr_addition': 'HouseNrAddition',
        'zip_code': 'ZipCode',
        'city': 'City',
        'region': 'Region',
        'country_iso': 'CountryIso',
        'original': 'Original'
    }

    def __init__(self, gender=None, company_name=None, first_name=None, last_name=None, street_name=None, house_nr=None, house_nr_addition=None, zip_code=None, city=None, region=None, country_iso=None, original=None, local_vars_configuration=None):  # noqa: E501
        """ChannelAddressRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._gender = None
        self._company_name = None
        self._first_name = None
        self._last_name = None
        self._street_name = None
        self._house_nr = None
        self._house_nr_addition = None
        self._zip_code = None
        self._city = None
        self._region = None
        self._country_iso = None
        self._original = None
        self.discriminator = None

        self.gender = gender
        self.company_name = company_name
        self.first_name = first_name
        self.last_name = last_name
        self.street_name = street_name
        self.house_nr = house_nr
        self.house_nr_addition = house_nr_addition
        self.zip_code = zip_code
        self.city = city
        self.region = region
        self.country_iso = country_iso
        self.original = original

    @property
    def gender(self):
        """Gets the gender of this ChannelAddressRequest.  # noqa: E501

        Optional. The customer's gender.  # noqa: E501

        :return: The gender of this ChannelAddressRequest.  # noqa: E501
        :rtype: Gender
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this ChannelAddressRequest.

        Optional. The customer's gender.  # noqa: E501

        :param gender: The gender of this ChannelAddressRequest.  # noqa: E501
        :type gender: Gender
        """

        self._gender = gender

    @property
    def company_name(self):
        """Gets the company_name of this ChannelAddressRequest.  # noqa: E501

        Optional. Company addressed too.  # noqa: E501

        :return: The company_name of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this ChannelAddressRequest.

        Optional. Company addressed too.  # noqa: E501

        :param company_name: The company_name of this ChannelAddressRequest.  # noqa: E501
        :type company_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                company_name is not None and len(company_name) > 50):
            raise ValueError("Invalid value for `company_name`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                company_name is not None and len(company_name) < 0):
            raise ValueError("Invalid value for `company_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._company_name = company_name

    @property
    def first_name(self):
        """Gets the first_name of this ChannelAddressRequest.  # noqa: E501

        The first name of the customer.  # noqa: E501

        :return: The first_name of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ChannelAddressRequest.

        The first name of the customer.  # noqa: E501

        :param first_name: The first_name of this ChannelAddressRequest.  # noqa: E501
        :type first_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) > 50):
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) < 0):
            raise ValueError("Invalid value for `first_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ChannelAddressRequest.  # noqa: E501

        The last name of the customer (includes the surname prefix [tussenvoegsel] like 'de', 'van', 'du').  # noqa: E501

        :return: The last_name of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ChannelAddressRequest.

        The last name of the customer (includes the surname prefix [tussenvoegsel] like 'de', 'van', 'du').  # noqa: E501

        :param last_name: The last_name of this ChannelAddressRequest.  # noqa: E501
        :type last_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) > 50):
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) < 0):
            raise ValueError("Invalid value for `last_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._last_name = last_name

    @property
    def street_name(self):
        """Gets the street_name of this ChannelAddressRequest.  # noqa: E501

        The name of the street (without house number information)  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :return: The street_name of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this ChannelAddressRequest.

        The name of the street (without house number information)  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :param street_name: The street_name of this ChannelAddressRequest.  # noqa: E501
        :type street_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                street_name is not None and len(street_name) > 50):
            raise ValueError("Invalid value for `street_name`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                street_name is not None and len(street_name) < 0):
            raise ValueError("Invalid value for `street_name`, length must be greater than or equal to `0`")  # noqa: E501

        self._street_name = street_name

    @property
    def house_nr(self):
        """Gets the house_nr of this ChannelAddressRequest.  # noqa: E501

        The house number  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :return: The house_nr of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._house_nr

    @house_nr.setter
    def house_nr(self, house_nr):
        """Sets the house_nr of this ChannelAddressRequest.

        The house number  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :param house_nr: The house_nr of this ChannelAddressRequest.  # noqa: E501
        :type house_nr: str
        """
        if (self.local_vars_configuration.client_side_validation and
                house_nr is not None and len(house_nr) > 50):
            raise ValueError("Invalid value for `house_nr`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                house_nr is not None and len(house_nr) < 0):
            raise ValueError("Invalid value for `house_nr`, length must be greater than or equal to `0`")  # noqa: E501

        self._house_nr = house_nr

    @property
    def house_nr_addition(self):
        """Gets the house_nr_addition of this ChannelAddressRequest.  # noqa: E501

        Optional. Addition to the house number  If the address is: Groenhazengracht 2c, the address will be:  StreetName: Groenhazengracht  HouseNo: 2  HouseNrAddition: c  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :return: The house_nr_addition of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._house_nr_addition

    @house_nr_addition.setter
    def house_nr_addition(self, house_nr_addition):
        """Sets the house_nr_addition of this ChannelAddressRequest.

        Optional. Addition to the house number  If the address is: Groenhazengracht 2c, the address will be:  StreetName: Groenhazengracht  HouseNo: 2  HouseNrAddition: c  This field might be empty if address validation is disabled in ChannelEngine.  # noqa: E501

        :param house_nr_addition: The house_nr_addition of this ChannelAddressRequest.  # noqa: E501
        :type house_nr_addition: str
        """
        if (self.local_vars_configuration.client_side_validation and
                house_nr_addition is not None and len(house_nr_addition) > 50):
            raise ValueError("Invalid value for `house_nr_addition`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                house_nr_addition is not None and len(house_nr_addition) < 0):
            raise ValueError("Invalid value for `house_nr_addition`, length must be greater than or equal to `0`")  # noqa: E501

        self._house_nr_addition = house_nr_addition

    @property
    def zip_code(self):
        """Gets the zip_code of this ChannelAddressRequest.  # noqa: E501

        The zip or postal code.  # noqa: E501

        :return: The zip_code of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._zip_code

    @zip_code.setter
    def zip_code(self, zip_code):
        """Sets the zip_code of this ChannelAddressRequest.

        The zip or postal code.  # noqa: E501

        :param zip_code: The zip_code of this ChannelAddressRequest.  # noqa: E501
        :type zip_code: str
        """

        self._zip_code = zip_code

    @property
    def city(self):
        """Gets the city of this ChannelAddressRequest.  # noqa: E501

        The name of the city.  # noqa: E501

        :return: The city of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this ChannelAddressRequest.

        The name of the city.  # noqa: E501

        :param city: The city of this ChannelAddressRequest.  # noqa: E501
        :type city: str
        """
        if (self.local_vars_configuration.client_side_validation and
                city is not None and len(city) > 50):
            raise ValueError("Invalid value for `city`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                city is not None and len(city) < 0):
            raise ValueError("Invalid value for `city`, length must be greater than or equal to `0`")  # noqa: E501

        self._city = city

    @property
    def region(self):
        """Gets the region of this ChannelAddressRequest.  # noqa: E501

        Optional. State/province/region.  # noqa: E501

        :return: The region of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this ChannelAddressRequest.

        Optional. State/province/region.  # noqa: E501

        :param region: The region of this ChannelAddressRequest.  # noqa: E501
        :type region: str
        """
        if (self.local_vars_configuration.client_side_validation and
                region is not None and len(region) > 50):
            raise ValueError("Invalid value for `region`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                region is not None and len(region) < 0):
            raise ValueError("Invalid value for `region`, length must be greater than or equal to `0`")  # noqa: E501

        self._region = region

    @property
    def country_iso(self):
        """Gets the country_iso of this ChannelAddressRequest.  # noqa: E501

        For example: NL, BE, FR.  # noqa: E501

        :return: The country_iso of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._country_iso

    @country_iso.setter
    def country_iso(self, country_iso):
        """Sets the country_iso of this ChannelAddressRequest.

        For example: NL, BE, FR.  # noqa: E501

        :param country_iso: The country_iso of this ChannelAddressRequest.  # noqa: E501
        :type country_iso: str
        """
        if (self.local_vars_configuration.client_side_validation and
                country_iso is not None and len(country_iso) > 2):
            raise ValueError("Invalid value for `country_iso`, length must be less than or equal to `2`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                country_iso is not None and len(country_iso) < 0):
            raise ValueError("Invalid value for `country_iso`, length must be greater than or equal to `0`")  # noqa: E501

        self._country_iso = country_iso

    @property
    def original(self):
        """Gets the original of this ChannelAddressRequest.  # noqa: E501

        Optional. The address as a single string: use in case the address lines are entered  as single lines and later parsed into street, house number and house number addition.  # noqa: E501

        :return: The original of this ChannelAddressRequest.  # noqa: E501
        :rtype: str
        """
        return self._original

    @original.setter
    def original(self, original):
        """Sets the original of this ChannelAddressRequest.

        Optional. The address as a single string: use in case the address lines are entered  as single lines and later parsed into street, house number and house number addition.  # noqa: E501

        :param original: The original of this ChannelAddressRequest.  # noqa: E501
        :type original: str
        """
        if (self.local_vars_configuration.client_side_validation and
                original is not None and len(original) > 256):
            raise ValueError("Invalid value for `original`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                original is not None and len(original) < 0):
            raise ValueError("Invalid value for `original`, length must be greater than or equal to `0`")  # noqa: E501

        self._original = original

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelAddressRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelAddressRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelProcessedChangesRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created': 'list[ChannelProductReferencesRequest]',
        'updated': 'list[str]',
        'removed': 'list[str]'
    }

    attribute_map = {
        'created': 'Created',
        'updated': 'Updated',
        'removed': 'Removed'
    }

    def __init__(self, created=None, updated=None, removed=None, local_vars_configuration=None):  # noqa: E501
        """ChannelProcessedChangesRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created = None
        self._updated = None
        self._removed = None
        self.discriminator = None

        self.created = created
        self.updated = updated
        self.removed = removed

    @property
    def created(self):
        """Gets the created of this ChannelProcessedChangesRequest.  # noqa: E501

        A collection of pairs of merchant and channel references  of the products which are successfully created. The channel references  are saved such that in subsequent calls these can be used instead of the  merchant references.  # noqa: E501

        :return: The created of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[ChannelProductReferencesRequest]
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ChannelProcessedChangesRequest.

        A collection of pairs of merchant and channel references  of the products which are successfully created. The channel references  are saved such that in subsequent calls these can be used instead of the  merchant references.  # noqa: E501

        :param created: The created of this ChannelProcessedChangesRequest.  # noqa: E501
        :type created: list[ChannelProductReferencesRequest]
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this ChannelProcessedChangesRequest.  # noqa: E501

        The channel references of the products which are successfully updated.  # noqa: E501

        :return: The updated of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ChannelProcessedChangesRequest.

        The channel references of the products which are successfully updated.  # noqa: E501

        :param updated: The updated of this ChannelProcessedChangesRequest.  # noqa: E501
        :type updated: list[str]
        """

        self._updated = updated

    @property
    def removed(self):
        """Gets the removed of this ChannelProcessedChangesRequest.  # noqa: E501

        The channel references of the products which are successfully removed.  # noqa: E501

        :return: The removed of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._removed

    @removed.setter
    def removed(self, removed):
        """Sets the removed of this ChannelProcessedChangesRequest.

        The channel references of the products which are successfully removed.  # noqa: E501

        :param removed: The removed of this ChannelProcessedChangesRequest.  # noqa: E501
        :type removed: list[str]
        """

        self._removed = removed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelProcessedChangesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelProcessedChangesRequest):
            return True

        return self.to_dict() != other.to_dict()



# flake8: noqa

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.13.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "2.13.0"

# import ApiClient
from channelengine_channel_api_client.api_client import ApiClient

# import Configuration
from channelengine_channel_api_client.configuration import Configuration

# import exceptions
from channelengine_channel_api_client.exceptions import OpenApiException
from channelengine_channel_api_client.exceptions import ApiAttributeError
from channelengine_channel_api_client.exceptions import ApiTypeError
from channelengine_channel_api_client.exceptions import ApiValueError
from channelengine_channel_api_client.exceptions import ApiKeyError
from channelengine_channel_api_client.exceptions import ApiException
